@@ -17,7 +17,7 @@ import logo32 from '../style/logos/python-logo-32x32.png';
 import logo64 from '../style/logos/python-logo-64x64.png';
 
 const server_kernel: JupyterLiteServerPlugin<void> = {
-  id: '@jupyterlite/xeus-kernel-extension:kernel',
+  id: '@jupyterlite/xeus-python-kernel-extension:kernel',
   autoStart: true,
   requires: [IKernelSpecs, IServiceWorkerRegistrationWrapper],
   activate: (
@@ -28,17 +28,9 @@ const server_kernel: JupyterLiteServerPlugin<void> = {
     kernelspecs.register({
       spec: {
         name: 'xeus-python',
-        display_name: 'xeus-python',
+        display_name: 'Python (XPython)',
         language: 'python',
         argv: [],
-        spec: {
-          argv: [],
-          env: {},
-          display_name: 'xeus-python',
-          language: 'python',
-          interrupt_mode: 'message',
-          metadata: {}
-        },
         resources: {
           'logo-32x32': logo32,
           'logo-64x64': logo64
