@@ -17,7 +17,7 @@ def test_python_env():
     addon = XeusPythonEnv(manager)
     addon.packages = ["numpy", "ipyleaflet"]
 
-    for step in addon.pre_build(manager):
+    for step in addon.post_build(manager):
         pass
 
     # Check env
